@@ -17,13 +17,16 @@ module Network.SOAP.Parsing.Stream
     , laxContent, flaxContent
     , readContent, readTag
       -- * Types to use in custom parser sinks
-    , Sink, Event
+    , Event
+    , ConduitM, Void
+    , Sink
     ) where
 
 #if MIN_VERSION_conduit(1,1,0)
 import Control.Monad.Catch (MonadThrow)
 #endif
-import Data.Conduit
+import Data.Conduit (ConduitM, Sink)
+import Data.Void (Void)
 import Data.XML.Types (Event)
 
 import           Text.XML (Name(..))
@@ -32,7 +35,7 @@ import qualified Text.XML.Stream.Parse as XSP
 import           Data.Text (Text, unpack)
 
 -- | Namespace- and attribute- ignorant tagNoAttr.
-laxTag :: (MonadThrow m) => Text -> Sink Event m a -> Sink Event m (Maybe a)
+laxTag :: (MonadThrow m) => Text -> ConduitM Event Void m a -> ConduitM Event Void m (Maybe a)
 #if MIN_VERSION_xml_conduit(1,5,0)
 laxTag ln = XSP.tag' (XSP.matching $ (== ln) . nameLocalName) XSP.ignoreAttrs . const
 #else
@@ -40,19 +43,19 @@ laxTag ln = XSP.tagPredicate ((== ln) . nameLocalName) XSP.ignoreAttrs . const
 #endif
 
 -- | Non-maybe version of laxTag/tagNoAttr.
-flaxTag :: (MonadThrow m) => Text -> Sink Event m a -> Sink Event m a
+flaxTag :: (MonadThrow m) => Text -> ConduitM Event Void m a -> ConduitM Event Void m a
 flaxTag ln s = XSP.force ("got no " ++ show ln) $ laxTag ln s
 
-laxContent :: (MonadThrow m) => Text -> Sink Event m (Maybe Text)
+laxContent :: (MonadThrow m) => Text -> ConduitM Event Void m (Maybe Text)
 laxContent ln = laxTag ln XSP.content
 
-flaxContent :: (MonadThrow m) => Text -> Sink Event m Text
+flaxContent :: (MonadThrow m) => Text -> ConduitM Event Void m Text
 flaxContent ln = flaxTag ln XSP.content
 
 -- | Unpack and read a current tag content.
-readContent :: (Read a, MonadThrow m) => Sink Event m a
+readContent :: (Read a, MonadThrow m) => ConduitM Event Void m a
 readContent = fmap (read . unpack) XSP.content
 
 -- | Unpack and read tag content by local name.
-readTag :: (Read a, MonadThrow m) => Text -> Sink Event m a
+readTag :: (Read a, MonadThrow m) => Text -> ConduitM Event Void m a
 readTag n = flaxTag n readContent
